<a id="mypy-boto3-mobile"></a>

# mypy-boto3-mobile

[![PyPI - mypy-boto3-mobile](https://img.shields.io/pypi/v/mypy-boto3-mobile.svg?color=blue)](https://pypi.org/project/mypy-boto3-mobile)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-mobile.svg?color=blue)](https://pypi.org/project/mypy-boto3-mobile)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-mobile?color=blue)](https://pypistats.org/packages/mypy-boto3-mobile)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Mobile 1.18.26](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/mobile.html#Mobile)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.1.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-mobile docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mobile/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-mobile](#mypy-boto3-mobile)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `Mobile` service.

```bash
python -m pip install boto3-stubs[mobile]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[mobile]` in your environment:
  `python -m pip install 'boto3-stubs[mobile]'`

Both type checking and auto-complete should work for `Mobile` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[mobile]` in your environment:
  `python -m pip install 'boto3-stubs[mobile]'`

Both type checking and auto-complete should work for `Mobile` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[mobile]` in your environment:
  `python -m pip install 'boto3-stubs[mobile]'`
- Run `mypy` as usual

Type checking should work for `Mobile` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[mobile]` in your environment:
  `python -m pip install 'boto3-stubs[mobile]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Mobile` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`MobileClient` provides annotations for `boto3.client("mobile")`.

```python
import boto3

from mypy_boto3_mobile import MobileClient

client: MobileClient = boto3.client("mobile")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: MobileClient = session.client("mobile")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_mobile.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_mobile import MobileClient
from mypy_boto3_mobile.paginator import (
    ListBundlesPaginator,
    ListProjectsPaginator,
)

client: MobileClient = boto3.client("mobile")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_bundles_paginator: ListBundlesPaginator = client.get_paginator("list_bundles")
list_projects_paginator: ListProjectsPaginator = client.get_paginator("list_projects")
```

<a id="literals"></a>

### Literals

`mypy_boto3_mobile.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_mobile.literals import (
    ListBundlesPaginatorName,
    ListProjectsPaginatorName,
    PlatformType,
    ProjectStateType,
)

def check_value(value: ListBundlesPaginatorName) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_mobile.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_mobile.type_defs import (
    BundleDetailsTypeDef,
    CreateProjectRequestRequestTypeDef,
    CreateProjectResultTypeDef,
    DeleteProjectRequestRequestTypeDef,
    DeleteProjectResultTypeDef,
    DescribeBundleRequestRequestTypeDef,
    DescribeBundleResultTypeDef,
    DescribeProjectRequestRequestTypeDef,
    DescribeProjectResultTypeDef,
    ExportBundleRequestRequestTypeDef,
    ExportBundleResultTypeDef,
    ExportProjectRequestRequestTypeDef,
    ExportProjectResultTypeDef,
    ListBundlesRequestRequestTypeDef,
    ListBundlesResultTypeDef,
    ListProjectsRequestRequestTypeDef,
    ListProjectsResultTypeDef,
    PaginatorConfigTypeDef,
    ProjectDetailsTypeDef,
    ProjectSummaryTypeDef,
    ResourceTypeDef,
    ResponseMetadataTypeDef,
    UpdateProjectRequestRequestTypeDef,
    UpdateProjectResultTypeDef,
)

def get_structure() -> BundleDetailsTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-mobile` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-mobile docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mobile/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
